@@ -3,7 +3,7 @@
 # from lazyearth.mainfile import water
 
 from lazyearth.mainfile import objearth
-from lazyearth.test_mainfile import water
+from lazyearth.mainfile import water
 
-__version__ = '0.0.61'
+__version__ = '0.0.62'
 print(f'Lazyearth version : {__version__}')
\ No newline at end of file
